@@ -293,63 +293,63 @@ SOURCES = {
     'aodh-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/aodh/'
-                     'aodh-10.0.0.tar.gz')},
+                     'aodh-stable-ussuri.tar.gz')},
     'barbican-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/barbican/'
-                     'barbican-10.0.0.tar.gz')},
+                     'barbican-stable-ussuri.tar.gz')},
     'bifrost-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/bifrost/'
-                     'bifrost-8.1.0.tar.gz')},
+                     'bifrost-stable-ussuri.tar.gz')},
     'blazar-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar/'
-                     'blazar-5.0.0.tar.gz')},
+                     'blazar-stable-ussuri.tar.gz')},
     'ceilometer-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ceilometer/'
-                     'ceilometer-14.0.0.tar.gz')},
+                     'ceilometer-stable-ussuri.tar.gz')},
     'ceilometer-base-plugin-panko': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/panko/'
-                     'panko-8.0.0.tar.gz')},
+                     'panko-stable-ussuri.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cinder/'
-                     'cinder-16.1.0.tar.gz')},
+                     'cinder-stable-ussuri.tar.gz')},
     'congress-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/congress/'
-                     'openstack-congress-11.0.0.tar.gz')},
+                     'congress-stable-ussuri.tar.gz')},
     'cloudkitty-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cloudkitty/'
-                     'cloudkitty-12.0.0.tar.gz')},
+                     'cloudkitty-stable-ussuri.tar.gz')},
     'cyborg-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cyborg/'
-                     'openstack-cyborg-4.0.0.tar.gz')},
+                     'cyborg-stable-ussuri.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/designate/'
-                     'designate-10.0.0.tar.gz')},
+                     'designate-stable-ussuri.tar.gz')},
     'ec2-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ec2-api/'
-                     'ec2-api-10.0.0.tar.gz')},
+                     'ec2-api-stable-ussuri.tar.gz')},
     'freezer-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer-api/'
-                     'freezer-api-8.0.0.tar.gz')},
+                     'freezer-api-stable-ussuri.tar.gz')},
     'freezer-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer/'
-                     'freezer-8.0.0.tar.gz')},
+                     'freezer-stable-ussuri.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/glance/'
-                     'glance-20.0.0.tar.gz')},
+                     'glance-stable-ussuri.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
         'reference': '4.3.4',
@@ -358,191 +358,191 @@ SOURCES = {
     'heat-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat/'
-                     'openstack-heat-14.0.0.tar.gz')},
+                     'heat-stable-ussuri.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/horizon/'
-                     'horizon-18.3.2.tar.gz')},
+                     'horizon-stable-ussuri.tar.gz')},
     'horizon-plugin-blazar-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-dashboard/'
-                     'blazar-dashboard-3.0.0.tar.gz')},
+                     'blazar-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-congress-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/congress-dashboard/'
-                     'congress-dashboard-6.0.0.tar.gz')},
+                     'congress-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-cloudkitty-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cloudkitty-dashboard/'
-                     'cloudkitty-dashboard-10.0.0.tar.gz')},
+                     'cloudkitty-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-designate-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/designate-dashboard/'
-                     'designate-dashboard-10.0.0.tar.gz')},
+                     'designate-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-fwaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-fwaas-dashboard/'
-                     'neutron-fwaas-dashboard-3.0.0.tar.gz')},
+                     'neutron-fwaas-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-freezer-web-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer-web-ui/'
-                     'freezer-web-ui-8.0.0.tar.gz')},
+                     'freezer-web-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-heat-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat-dashboard/'
-                     'heat-dashboard-3.0.0.tar.gz')},
+                     'heat-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-ironic-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-ui/'
-                     'ironic-ui-4.0.0.tar.gz')},
+                     'ironic-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-karbor-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/karbor-dashboard/'
-                     'karbor-dashboard-1.4.0.tar.gz')},
+                     'karbor-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-magnum-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum-ui/'
-                     'magnum-ui-6.0.0.tar.gz')},
+                     'magnum-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-manila-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila-ui/'
-                     'manila-ui-3.0.0.tar.gz')},
+                     'manila-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-masakari-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari-dashboard/'
-                     'masakari-dashboard-2.0.0.tar.gz')},
+                     'masakari-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-mistral-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral-dashboard/'
-                     'mistral-dashboard-10.0.0.tar.gz')},
+                     'mistral-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-monasca-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-ui/'
-                     'monasca-ui-2.0.1.tar.gz')},
+                     'monasca-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-murano-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano-dashboard/'
-                     'murano-dashboard-9.0.0.tar.gz')},
+                     'murano-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-neutron-vpnaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas-dashboard/'
-                     'neutron-vpnaas-dashboard-2.0.0.tar.gz')},
+                     'neutron-vpnaas-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-octavia-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/octavia-dashboard/'
-                     'octavia-dashboard-5.0.0.tar.gz')},
+                     'octavia-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-qinling-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/qinling-dashboard/'
-                     'qinling-dashboard-3.0.0.tar.gz')},
+                     'qinling-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-sahara-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-dashboard/'
-                     'sahara-dashboard-12.0.0.tar.gz')},
+                     'sahara-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-searchlight-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/searchlight-ui/'
-                     'searchlight-ui-8.0.0.tar.gz')},
+                     'searchlight-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-senlin-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/senlin-dashboard/'
-                     'senlin-dashboard-1.0.0.tar.gz')},
+                     'senlin-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-solum-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/solum-dashboard/'
-                     'solum-dashboard-4.0.0.tar.gz')},
+                     'solum-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-tacker-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker-horizon/'
-                     'tacker-horizon-1.0.0.tar.gz')},
+                     'tacker-horizon-stable-ussuri.tar.gz')},
     'horizon-plugin-trove-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove-dashboard/'
-                     'trove-dashboard-14.0.0.tar.gz')},
+                     'trove-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-vitrage-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage-dashboard/'
-                     'vitrage-dashboard-3.1.0.tar.gz')},
+                     'vitrage-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-watcher-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher-dashboard/'
-                     'watcher-dashboard-3.0.0.tar.gz')},
+                     'watcher-dashboard-stable-ussuri.tar.gz')},
     'horizon-plugin-zaqar-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zaqar-ui/'
-                     'zaqar-ui-8.0.0.tar.gz')},
+                     'zaqar-ui-stable-ussuri.tar.gz')},
     'horizon-plugin-zun-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zun-ui/'
-                     'zun-ui-5.0.0.tar.gz')},
+                     'zun-ui-stable-ussuri.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic/'
-                     'ironic-15.0.0.tar.gz')},
+                     'ironic-stable-ussuri.tar.gz')},
     'ironic-inspector': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-inspector/'
-                     'ironic-inspector-10.1.0.tar.gz')},
+                     'ironic-inspector-stable-ussuri.tar.gz')},
     'karbor-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/karbor/'
-                     'karbor-1.5.0.tar.gz')},
+                     'karbor-stable-ussuri.tar.gz')},
     'keystone-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/keystone/'
-                     'keystone-17.0.0.tar.gz')},
+                     'keystone-stable-ussuri.tar.gz')},
     'kuryr-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/kuryr/'
-                     'kuryr-lib-2.0.0.tar.gz')},
+                     'kuryr-stable-ussuri.tar.gz')},
     'kuryr-libnetwork': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/kuryr-libnetwork/'
-                     'kuryr-libnetwork-5.0.0.tar.gz')},
+                     'kuryr-libnetwork-stable-ussuri.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum/'
-                     'magnum-10.0.0.tar.gz')},
+                     'magnum-stable-ussuri.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila/'
-                     'manila-10.0.0.tar.gz')},
+                     'manila-stable-ussuri.tar.gz')},
     'masakari-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari/'
-                     'masakari-9.0.0.tar.gz')},
+                     'masakari-stable-ussuri.tar.gz')},
     'masakari-monitors': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari-monitors/'
-                     'masakari-monitors-9.0.0.tar.gz')},
+                     'masakari-monitors-stable-ussuri.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral/'
-                     'mistral-10.0.0.tar.gz')},
+                     'mistral-stable-ussuri.tar.gz')},
     'mistral-base-plugin-tacker': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker/'
-                     'tacker-3.0.0.tar.gz')},
+                     'tacker-stable-ussuri.tar.gz')},
     'monasca-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-agent/'
-                     'monasca-agent-3.0.1.tar.gz')},
+                     'monasca-agent-stable-ussuri.tar.gz')},
     'monasca-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-api/'
-                     'monasca-api-4.0.0.tar.gz')},
+                     'monasca-api-stable-ussuri.tar.gz')},
     'monasca-notification': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-notification/'
-                     'monasca-notification-2.0.0.tar.gz')},
+                     'monasca-notification-stable-ussuri.tar.gz')},
     'monasca-persister': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-persister/'
-                     'monasca-persister-2.0.0.tar.gz')},
+                     'monasca-persister-stable-ussuri.tar.gz')},
     'monasca-statsd': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-statsd/'
-                     'monasca-statsd-2.0.0.tar.gz')},
+                     'monasca-statsd-stable-ussuri.tar.gz')},
     # FIXME(dszumski): Use openstack tar when infra is fixed
     'monasca-thresh': {
         'type': 'url',
@@ -551,39 +551,39 @@ SOURCES = {
     'monasca-thresh-additions-monasca-common': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-common/'
-                     'monasca-common-3.1.0.tar.gz')},
+                     'monasca-common-stable-ussuri.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano/'
-                     'murano-9.0.0.tar.gz')},
+                     'murano-stable-ussuri.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron/'
-                     'neutron-16.0.0.tar.gz')},
+                     'neutron-stable-ussuri.tar.gz')},
     'neutron-base-plugin-neutron-fwaas': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-fwaas/'
-                     'neutron-fwaas-16.0.0.tar.gz')},
+                     'neutron-fwaas-stable-ussuri.tar.gz')},
     'neutron-base-plugin-networking-ansible': {
         'type': 'url',
         'location': ('$tarballs_base/x/networking-ansible/'
-                     'networking-ansible-${openstack_branch}.tar.gz')},
+                     'networking-ansible-stable-ussuri.tar.gz')},
     'neutron-base-plugin-networking-baremetal': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-baremetal/'
-                     'networking-baremetal-2.0.0.tar.gz')},
+                     'networking-baremetal-stable-ussuri.tar.gz')},
     'neutron-base-plugin-networking-generic-switch': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-generic-switch/'
-                     'networking-generic-switch-3.0.0.tar.gz')},
+                     'networking-generic-switch-stable-ussuri.tar.gz')},
     'neutron-base-plugin-networking-mlnx': {
         'type': 'url',
         'location': ('$tarballs_base/x/networking-mlnx/'
-                     'networking-mlnx-${openstack_branch}.tar.gz')},
+                     'networking-mlnx-stable-ussuri.tar.gz')},
     'neutron-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-10.0.0.tar.gz')},
+                     'networking-sfc-stable-ussuri.tar.gz')},
     'neutron-base-plugin-vmware-nsx': {
         'type': 'url',
         'location': ('$tarballs_base/x/vmware-nsx/'
@@ -591,47 +591,47 @@ SOURCES = {
     'neutron-base-plugin-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas/'
-                     'neutron-vpnaas-16.0.0.tar.gz')},
+                     'neutron-vpnaas-stable-ussuri.tar.gz')},
     'neutron-bgp-dragent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-16.0.0.tar.gz')},
+                     'neutron-dynamic-routing-stable-ussuri.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-odl': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-odl/'
-                     'networking-odl-16.0.0.tar.gz')},
+                     'networking-odl-stable-ussuri.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-bgpvpn': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-bgpvpn/'
-                     'networking-bgpvpn-12.0.0.tar.gz')},
+                     'networking-bgpvpn-stable-ussuri.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-l2gw': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-l2gw/'
-                     'networking-l2gw-16.0.0.tar.gz')},
+                     'networking-l2gw-stable-ussuri.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-10.0.0.tar.gz')},
+                     'networking-sfc-stable-ussuri.tar.gz')},
     'neutron-server-plugin-neutron-dynamic-routing': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-16.0.0.tar.gz')},
+                     'neutron-dynamic-routing-stable-ussuri.tar.gz')},
     'neutron-server-plugin-vmware-nsxlib': {
         'type': 'url',
         'location': ('$tarballs_base/x/vmware-nsxlib/'
-                     'vmware-nsxlib-16.0.1.tar.gz')},
+                     'vmware-nsxlib-stable-ussuri.tar.gz')},
     'neutron-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas/'
-                     'neutron-vpnaas-16.0.0.tar.gz')},
+                     'neutron-vpnaas-stable-ussuri.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/nova/'
-                     'nova-21.0.0.tar.gz')},
+                     'nova-stable-ussuri.tar.gz')},
     'nova-base-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-nova/'
-                     'blazar-nova-2.0.0.tar.gz')},
+                     'blazar-nova-stable-ussuri.tar.gz')},
     'nova-base-plugin-mksproxy': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/nova-mksproxy/'
@@ -643,23 +643,23 @@ SOURCES = {
     'octavia-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/octavia/'
-                     'octavia-6.0.1.tar.gz')},
+                     'octavia-stable-ussuri.tar.gz')},
     'octavia-api-plugin-ovn-octavia-provider': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ovn-octavia-provider/'
-                     'ovn-octavia-provider-0.1.0.tar.gz')},
+                     'ovn-octavia-provider-stable-ussuri.tar.gz')},
     'panko-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/panko/'
-                     'panko-8.0.0.tar.gz')},
+                     'panko-stable-ussuri.tar.gz')},
     'placement-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/placement/'
-                     'openstack-placement-3.0.0.tar.gz')},
+                     'placement-stable-ussuri.tar.gz')},
     'qinling-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/qinling/'
-                     'qinling-4.0.0.tar.gz')},
+                     'qinling-stable-ussuri.tar.gz')},
     'tempest-plugin-tempest-conf': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/python-tempestconf/'
@@ -748,58 +748,62 @@ SOURCES = {
         'type': 'url',
         'location': ('$tarballs_base/openstack/rally/'
                      'rally-3.1.0.tar.gz')},
+    'rally-plugin-openstack': {
+        'type': 'url',
+        'location': ('$tarballs_base/openstack/rally-openstack/'
+                     'rally-openstack-2.0.0.tar.gz')},
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara/'
-                     'sahara-12.0.0.tar.gz')},
+                     'sahara-stable-ussuri.tar.gz')},
     'sahara-base-plugin-ambari': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-ambari/'
-                     'sahara-plugin-ambari-3.0.0.tar.gz')},
+                     'sahara-plugin-ambari-stable-ussuri.tar.gz')},
     'sahara-base-plugin-cdh': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-cdh/'
-                     'sahara-plugin-cdh-3.0.0.tar.gz')},
+                     'sahara-plugin-cdh-stable-ussuri.tar.gz')},
     'sahara-base-plugin-mapr': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-mapr/'
-                     'sahara-plugin-mapr-3.0.0.tar.gz')},
+                     'sahara-plugin-mapr-stable-ussuri.tar.gz')},
     'sahara-base-plugin-spark': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-spark/'
-                     'sahara-plugin-spark-3.0.0.tar.gz')},
+                     'sahara-plugin-spark-stable-ussuri.tar.gz')},
     'sahara-base-plugin-storm': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-storm/'
-                     'sahara-plugin-storm-3.0.0.tar.gz')},
+                     'sahara-plugin-storm-stable-ussuri.tar.gz')},
     'sahara-base-plugin-vanilla': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-vanilla/'
-                     'sahara-plugin-vanilla-3.0.0.tar.gz')},
+                     'sahara-plugin-vanilla-stable-ussuri.tar.gz')},
     'searchlight-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/searchlight/'
-                     'searchlight-8.0.0.tar.gz')},
+                     'searchlight-stable-ussuri.tar.gz')},
     'senlin-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/senlin/'
-                     'senlin-9.0.0.tar.gz')},
+                     'senlin-stable-ussuri.tar.gz')},
     'solum-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/solum/'
-                     'solum-8.0.0.tar.gz')},
+                     'solum-stable-ussuri.tar.gz')},
     'swift-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/swift/'
-                     'swift-2.25.0.tar.gz')},
+                     'swift-stable-ussuri.tar.gz')},
     'tacker-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker/'
-                     'tacker-3.0.0.tar.gz')},
+                     'tacker-stable-ussuri.tar.gz')},
     'tacker-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-10.0.0.tar.gz')},
+                     'networking-sfc-stable-ussuri.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tempest/'
@@ -807,15 +811,15 @@ SOURCES = {
     'tripleoclient': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/python-tripleoclient/'
-                     'tripleoclient-13.2.0.tar.gz')},
+                     'tripleoclient-stable-ussuri.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove/'
-                     'trove-13.0.0.tar.gz')},
+                     'trove-stable-ussuri.tar.gz')},
     'vitrage-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage/'
-                     'vitrage-7.1.0.tar.gz')},
+                     'vitrage-stable-ussuri.tar.gz')},
     'vmtp': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vmtp/'
@@ -823,15 +827,15 @@ SOURCES = {
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher/'
-                     'python-watcher-4.0.0.tar.gz')},
+                     'watcher-stable-ussuri.tar.gz')},
     'zaqar-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zaqar/'
-                     'zaqar-10.0.0.tar.gz')},
+                     'zaqar-stable-ussuri.tar.gz')},
     'zun-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zun/'
-                     'zun-5.0.0.tar.gz')}
+                     'zun-stable-ussuri.tar.gz')}
 }
 
 
